      SUBROUTINE QCFFT (C, N, F)
C-----------------------------------------------------------------------
C! Pseudo AP routine: Complex 1-D FFT.
C# AP-FFT
C-----------------------------------------------------------------------
C;  Copyright (C) 1995
C;  Associated Universities, Inc. Washington DC, USA.
C;
C;  This program is free software; you can redistribute it and/or
C;  modify it under the terms of the GNU General Public License as
C;  published by the Free Software Foundation; either version 2 of
C;  the License, or (at your option) any later version.
C;
C;  This program is distributed in the hope that it will be useful,
C;  but WITHOUT ANY WARRANTY; without even the implied warranty of
C;  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C;  GNU General Public License for more details.
C;
C;  You should have received a copy of the GNU General Public
C;  License along with this program; if not, write to the Free
C;  Software Foundation, Inc., 675 Massachusetts Ave, Cambridge,
C;  MA 02139, USA.
C;
C;  Correspondence concerning AIPS should be addressed as follows:
C;         Internet email: aipsmail@nrao.edu.
C;         Postal address: AIPS Project Office
C;                         National Radio Astronomy Observatory
C;                         520 Edgemont Road
C;                         Charlottesville, VA 22903-2475 USA
C-----------------------------------------------------------------------
C-----------------------------------------------------------------------
C   Full complex 1-D FFT.
C   Inputs:
C      C  I  Base address (0-rel) of complex array to transform
C      N  I  Number of points in array (must be power of two).
C      F  I  Transform direction; 1 -> Forward
C                                -1 -> Backward
C   Input/Output in Common (Include DAPC)
C      WRKFFT(*)  R    Table used in FFT
C      FFTDIR     I    Direction of FFT, used to determine if
C                      WRKFFT needs to be initilized.
C      FFTSZE     I    Size of FFT, used to determine if WRKFFT
C                      needs to be initilized.
C   Usage notes:
C      The array WRKFFT is used to contain the tables necessary for
C   FFTs.  QCFFT initilizes this table if F*2 .NE. FFTDIR or N .NE.
C   FFTSZE.
C   CRI version - WKVECB is used.
C-----------------------------------------------------------------------
      INTEGER   C, N, F
      INCLUDE 'INCS:DAPC.INC'
      INTEGER  IF
C-----------------------------------------------------------------------
      IF (N.LE.0) GO TO 999
      IF = -F
C                                       Init table.
      IF (((2*F).NE.FFTDIR) .OR. (N.NE.FFTSZE)) THEN
         CALL CFFT2 (1, IF, N, WKVECB, WRKFFT, WKVECB)
         FFTDIR = F * 2
         FFTSZE = N
         END IF
C
      CALL CFFT2 (0, IF, N, APCORE(C+1), WRKFFT, APCORE(C+1))
C
 999  RETURN
      END
